@@ -4,7 +4,7 @@
 
 ;; Author: Claire Rodriguez <yewscion@gmail.com>
 ;; Keywords: lisp
-;; Version: 0.0.4
+;; Version: 0.0.5
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -948,6 +948,159 @@ Can rely on current region. If optional STR argument is specified, this is a CAL
                                                         (replace-regexp-in-string
                                                          "[_']" "" str)))))))
 
+(defun cdr255:operate-on-region (action &optional lst)
+  "Apply ACTION to the current region, using LST as a possible list of
+supplementary data.
+
+This is an ACTION.
+
+Arguments
+=========
+
+ACTION<procedure>: The action that will be performed on the current
+                   region. Should have parameters like (foo REGION-START
+                   REGION-END LIST-OF-DATA).
+
+LST<list>: An optional list of data that will be passed as the last
+           argument to ACTION.
+
+Returns
+=======
+
+An <object> representing the result of applying ACTION on the current
+region.
+
+Impurities
+==========
+
+Uses the content of the current region."
+  (apply action (list (region-beginning) (region-end) lst)))
+
+(defun cdr255:replace-region (action &optional lst)
+  "Apply ACTION to the current region, using LST as a possible list of
+supplementary data.
+
+This is an ACTION.
+
+Arguments
+=========
+
+ACTION<procedure>: The action that will be performed on the current
+                   region. Should have parameters like (foo REGION-START
+                   REGION-END LIST-OF-DATA).
+
+LST<list>: An optional list of data that will be passed as the last
+           argument to ACTION.
+
+Returns
+=======
+
+<undefined>
+
+Impurities
+==========
+
+Replaces the content of the current region with the result of applying
+ACTION to that region's content, along with LST."
+  (let ((result (cdr255:operate-on-region action lst)))
+    (delete-region (region-beginning) (region-end))
+    (insert result)))
+
+(defun cdr255:convert-string-as-characters (str
+                                           conversion-proc)
+  "Convert STR character-by-character using a given
+CONVERSION-PROC -edure into a list of characters.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+STR<string>: The string to operate on.
+
+CONVERSION-PROC<procedure>: A procedure that takes a character as its
+                            sole parameter.
+
+Returns
+=======
+
+A <<list> of <objects>> denoting STR as interpreted through CONVERSION-PROC.
+
+Impurities
+==========
+
+None."
+   (mapcar conversion-proc
+           (string-to-list str)))
+
+(defun cdr255:and (x y)
+  "Logical AND with two arguments. For use with reduce.
+
+This is a CALCULATION. This is a wrapper for a special form.
+
+Arguments
+=========
+
+X<object>: One of the objects to test.
+
+Y<object>: The other object to test.
+
+Returns
+=======
+
+A <boolean>. <true> if both X and Y are true. <false> otherwise.
+
+Impurities
+==========
+
+None."
+  (and x y))
+
+(defun cdr255:or (x y)
+    "Logical OR with two arguments. For use with reduce.
+
+This is a CALCULATION. This is a wrapper for a special form.
+
+Arguments
+=========
+
+X<object>: One of the objects to test.
+
+Y<object>: The other object to test.
+
+Returns
+=======
+
+A <boolean>. <true> if both or either of X and Y are true. <false> otherwise.
+
+Impurities
+==========
+
+None."
+  (and x y))
+
+(defun cdr255:to-boolean (x)
+  "Converts X into `t' if truthy, or `nil' if falsey.
+
+This is a CALCULATION. This is lossy.
+
+Arguments
+=========
+
+X<object>: The value being considered.
+
+Returns
+=======
+
+A <boolean>. <true> if X is truthy, <false> otherwise.
+
+Impurities
+==========
+
+None."
+  (not (not x)))
+
+
 (provide 'cdr255)
 ;;; cdr255.el ends here
 
